Animanager Documentation
========================

Animanager_ is a command line program for advanced anime watching management.

.. _Animanager: https://www.felesatra.moe/animanager/

User guide
----------

.. toctree::
   :maxdepth: 1

   install
   quickstart
   cli
   aid-selection
   adding
   search
   cmdref
   watching

Developer guide
---------------

.. toctree::
   :maxdepth: 1

   dev/anidb
   dev/date
   dev/files
   dev/objects
   dev/sqlite
   dev/utils
   dev/xml

Indices and tables
==================

- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`
